==> watchdog_live-5.x-1.0.tar.gz: watchdog_live/watchdog_live.js <==
// $Id: watchdog_live.js,v 1.1 2008/01/23 19:12:20 stevemckenzie Exp $

Drupal.watchdog = {
  // Attach functionality.
  autoAttach: function() {
    // Grab settings.
    Drupal.watchdog.interval = $('#edit-watchdog-live-interval').val();
    Drupal.watchdog.disabled = $('#edit-watchdog-live-disabled').attr('checked') || 0;
    
    // Interval setting.
    $('#edit-watchdog-live-interval').bind('change', function(event) {
      Drupal.watchdog.saveSetting('interval', this.value);
    });
    
    // Disabled state.
    $('#edit-watchdog-live-disabled').bind('click', function(event) {
      Drupal.watchdog.saveSetting('disabled', this.checked);
      if (!this.checked) {
        Drupal.watchdog.start();
      }
    });
    
    // Handle updating.
    Drupal.watchdog.start();
  },
  
  // Check callback for update and display new content if any.
  load: function() {
    $.get(Drupal.settings.watchdogLive.basePath +'admin/logs/watchdog/live/callback', function(data) {
      var result = Drupal.parseJson(data);
      
      // Only if we get content back.
      if (result.content) {
        // Preload in a hidden div.
        $(document.body).append($('<div>').attr('id', 'watchdog-live-hidden').hide().html(result.content));
        
        // Remove the form from the preloaded content.
        $('#watchdog-live-hidden').children('#watchdog-form-overview').remove();
        
        var animated = false;
        $('#watchdog-form-overview').parent().children().not('#watchdog-form-overview').fadeOut('fast', function() {
          // Since we have multiple children, the callback will be called multiple times.
          // Force a stop.
          if (animated) { 
           return false; 
          }
          animated = true;
          
          // Remove old table.
          $('#watchdog-form-overview').parent().children().not('#watchdog-form-overview').remove();
          
          // Bring in new content.
          $('#watchdog-form-overview').parent().append($('#watchdog-live-hidden').children().hide());
          $('#watchdog-form-overview').parent().children().not('#watchdog-form-overview').fadeIn('fast');
        });
      }
      
      // Continue the loop.
      Drupal.watchdog.start();
    });
  },
  
  // Save a setting for the configurable options.
  saveSetting: function(name, value) {
    $.post(Drupal.settings.watchdogLive.basePath +'admin/logs/watchdog/live/settings', {name: value})
    Drupal.watchdog[name] = value;
  },
  
  // Start the process.
  start: function() {
    if (!Drupal.watchdog.disabled) {
      Drupal.watchdog.timeoutId = setTimeout(Drupal.watchdog.load, Drupal.watchdog.interval);
    }
  }
  
};

// Global Killswitch.
if (Drupal.jsEnabled) {
  $(document).ready(Drupal.watchdog.autoAttach);
}

==> watchdog_live-5.x-1.1.tar.gz: watchdog_live/watchdog_live.js <==
// $Id: watchdog_live.js,v 1.2 2008/01/28 22:43:26 stevemckenzie Exp $

Drupal.watchdog = {
  // Attach functionality.
  autoAttach: function() {
    // Grab settings.
    Drupal.watchdog.interval = $('#edit-watchdog-live-interval').val();
    Drupal.watchdog.disabled = $('#edit-watchdog-live-disabled').attr('checked') || 0;
    
    // Interval setting.
    $('#edit-watchdog-live-interval').bind('change', function(event) {
      Drupal.watchdog.saveSetting('interval', this.value);
    });
    
    // Disabled state.
    $('#edit-watchdog-live-disabled').bind('click', function(event) {
      Drupal.watchdog.saveSetting('disabled', this.checked);
      if (!this.checked) {
        Drupal.watchdog.start();
      }
    });
    
    // Handle updating.
    Drupal.watchdog.start();
  },
  
  // Check callback for update and display new content if any.
  load: function() {
    $.get(Drupal.settings.watchdogLive.basePath +'admin/logs/watchdog/live/callback', function(data) {
      var result = Drupal.parseJson(data);
      
      // Only if we get content back.
      if (result.content) {
        var animated = false;
        $('#watchdog-form-overview').parent().children().not('#watchdog-form-overview').fadeOut('fast', function() {
          // Since we have multiple children, the callback will be called multiple times.
          // Force a stop.
          if (animated) { 
           return false; 
          }
          animated = true;
          
          // Remove old table.
          $('#watchdog-form-overview').parent().children().not('#watchdog-form-overview').remove();
          
          // Bring in new content.
          $('#watchdog-form-overview').parent().append(result.content);
          $('#watchdog-form-overview').parent().children().not('#watchdog-form-overview').fadeIn('fast');
        });
      }
      
      // Continue the loop.
      Drupal.watchdog.start();
    });
  },
  
  // Save a setting for the configurable options.
  saveSetting: function(name, value) {
    $.post(Drupal.settings.watchdogLive.basePath +'admin/logs/watchdog/live/settings', {name: value})
    Drupal.watchdog[name] = value;
  },
  
  // Start the process.
  start: function() {
    if (!Drupal.watchdog.disabled) {
      Drupal.watchdog.timeoutId = setTimeout(Drupal.watchdog.load, Drupal.watchdog.interval);
    }
  }
  
};

// Global Killswitch.
if (Drupal.jsEnabled) {
  $(document).ready(Drupal.watchdog.autoAttach);
}
